package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.gitlab.GitConfiguration
import de.fraunhofer.iem.dataprovider.gitlab.Platform
import de.fraunhofer.iem.dataprovider.taskManager.model.Event
import de.fraunhofer.iem.dataprovider.taskManager.model.GetGitlabProjectDone
import de.fraunhofer.iem.dataprovider.toolRun.ToolRunService
import org.gitlab4j.api.GitLabApi


class GetGitlabProjectTask(
    private val repoId: Long,
    private val gitlabConfiguration: GitConfiguration,
    override val responseChannel: suspend (event: Event) -> Unit,
    private val toolRunService: ToolRunService
) : Task() {


    private val gitlabApi: GitLabApi = GitLabApi(gitlabConfiguration.host, gitlabConfiguration.accessToken)

    override suspend fun execute() {
        logger.info("Gitlab config ${gitlabConfiguration.host} ${gitlabConfiguration.accessToken}")

        val project = gitlabApi.projectApi.getProject(repoId)
        logger.info(project.toString())
        val projectUri = project.httpUrlToRepo

        val gitRepository = GitRepository(project.path, projectUri, repoId, Platform.OPEN_CODE)

        val repo = toolRunService.getRepoOrCreate(gitRepository)

        logger.info("Retrieved project ${project.path} and url $projectUri")

        responseChannel(GetGitlabProjectDone(taskID, repo.id!!, gitRepository))
    }
}
